@@ -20,8 +20,8 @@ class DefaultValue(BaseModel):
 
 
 class ColumnAttributes(BaseModel):
-    data_type: str  # This will need to be standardized
-    default_value: DefaultValue = DefaultValue(has_default_value=False)
+    data_type: Optional[str]  # This will need to be standardized
+    default_value: Optional[DefaultValue]
     is_nullable: Optional[bool]
     is_primary_key: Optional[bool]
 
@@ -36,11 +36,15 @@ class GraiNodeMetadata(BaseModel):
     node_attributes: Any
 
 
-class Column(GraiNodeMetadata):
+class ColumnMetadata(GraiNodeMetadata):
     node_type: Literal["Column"] = "Column"
     node_attributes: ColumnAttributes
 
 
-class Table(GraiNodeMetadata):
+class TableMetadata(GraiNodeMetadata):
     node_type: Literal["Table"] = "Table"
     node_attributes: TableAttributes
+
+
+class GraiEdgeMetadata(BaseModel):
+    version: Literal["v1"] = "v1"
